@@ -19,7 +19,7 @@
 #include <imath.hpp>
 #include <generate.hpp>
 #include <PhiTiny.hpp>
-#include <S1.hpp>
+#include <S.hpp>
 
 #include <stdint.h>
 #include <vector>
@@ -37,12 +37,12 @@ namespace {
 int64_t S2(int64_t x,
            int64_t y,
            int64_t c,
-           vector<int32_t>& primes,
-           vector<int32_t>& lpf,
-           vector<int32_t>& mu)
+           int64_t pi_y,
+           const vector<int32_t>& primes,
+           const vector<int32_t>& lpf,
+           const vector<int32_t>& mu)
 {
-  int64_t limit = x / y + 1;
-  int64_t pi_y = pi_bsearch(primes, y);
+  int64_t limit = x / y;
   int64_t s2 = 0;
   int64_t b = 1;
   vector<char> sieve(limit, 1);
@@ -100,19 +100,20 @@ int64_t pi_lmo2(int64_t x)
   if (x < 2)
     return 0;
 
+  bool threads = 1;
   double alpha = get_alpha_lmo(x);
   int64_t x13 = iroot<3>(x);
   int64_t y = (int64_t) (x13 * alpha);
   int64_t c = PhiTiny::get_c(y);
-  int64_t p2 = P2(x, y, 1);
+  int64_t p2 = P2(x, y, threads);
 
   auto primes = generate_primes<int32_t>(y);
   auto lpf = generate_lpf(y);
   auto mu = generate_moebius(y);
 
   int64_t pi_y = primes.size() - 1;
-  int64_t s1 = S1(x, y, c, 1);
-  int64_t s2 = S2(x, y, c, primes, lpf, mu);
+  int64_t s1 = S1(x, y, c, threads);
+  int64_t s2 = S2(x, y, c, pi_y, primes, lpf, mu);
   int64_t phi = s1 + s2;
   int64_t sum = phi + pi_y - 1 - p2;
 
