@@ -4,16 +4,16 @@
 ///         S1(x, y) used in the Lagarias-Miller-Odlyzko
 ///         and Deleglise-Rivat prime counting algorithms.
 ///
-/// Copyright (C) 2017 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2019 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
 ///
 
-#include <S1.hpp>
 #include <generate.hpp>
 #include <PhiTiny.hpp>
 #include <imath.hpp>
+#include <S.hpp>
 
 #include <stdint.h>
 #include <iostream>
@@ -36,6 +36,7 @@ int main()
   random_device rd;
   mt19937 gen(rd());
   uniform_int_distribution<int> dist(0, 10000000);
+  int threads = 1;
 
   for (int i = 0; i < 1000; i++)
   {
@@ -54,7 +55,7 @@ int main()
         s1 += mu[n] * phi_tiny(x / n, c);
 
     cout << "S1(" << x << ", " << y << ") = " << s1;
-    check(s1 == S1(x, y, c, 1));
+    check(s1 == S1(x, y, c, threads));
   }
 
   cout << endl;
