@@ -4,18 +4,18 @@
 ///         S2(x, y) used in the Lagarias-Miller-Odlyzko
 ///         and Deleglise-Rivat prime counting algorithms.
 ///
-/// Copyright (C) 2019 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2020 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
 ///
 
-#include <S2.hpp>
 #include <primecount.hpp>
 #include <primecount-internal.hpp>
 #include <PhiTiny.hpp>
 #include <generate.hpp>
 #include <imath.hpp>
+#include <S.hpp>
 
 #include <stdint.h>
 #include <iostream>
@@ -38,6 +38,7 @@ int main()
   random_device rd;
   mt19937 gen(rd());
   uniform_int_distribution<int> dist(1, 10000000);
+  int threads = 1;
 
   // test small x
   for (int i = 1; i < 30000; i++)
@@ -45,7 +46,7 @@ int main()
     int64_t x = i;
     double alpha = get_alpha_deleglise_rivat(x);
     int64_t y = (int64_t) (alpha * iroot<3>(x));
-    int64_t pi_y = pi_legendre(y, 1);
+    int64_t pi_y = pi_noprint(y, threads);
     int64_t z = x / y;
     int64_t c = PhiTiny::get_c(y);
     int64_t s2 = 0;
@@ -62,9 +63,9 @@ int main()
 
     cout << "S2(" << x << ", " << y << ") = " << s2;
 
-    check(s2 == S2_trivial(x, y, z, c) +
-                S2_easy(x, y, z, c, 1) +
-                S2_hard(x, y, z, c, Ri(x), 1));
+    check(s2 == S2_trivial(x, y, z, c, threads) +
+                S2_easy(x, y, z, c, threads) +
+                S2_hard(x, y, z, c, Ri(x), threads));
   }
 
   // test random x
@@ -73,7 +74,7 @@ int main()
     int64_t x = dist(gen);
     double alpha = get_alpha_deleglise_rivat(x);
     int64_t y = (int64_t) (alpha * iroot<3>(x));
-    int64_t pi_y = pi_legendre(y, 1);
+    int64_t pi_y = pi_noprint(y, threads);
     int64_t z = x / y;
     int64_t c = PhiTiny::get_c(y);
     int64_t s2 = 0;
@@ -90,9 +91,9 @@ int main()
 
     cout << "S2(" << x << ", " << y << ") = " << s2;
 
-    check(s2 == S2_trivial(x, y, z, c) +
-                S2_easy(x, y, z, c, 1) +
-                S2_hard(x, y, z, c, Ri(x), 1));
+    check(s2 == S2_trivial(x, y, z, c, threads) +
+                S2_easy(x, y, z, c, threads) +
+                S2_hard(x, y, z, c, Ri(x), threads));
   }
 
   cout << endl;
