@@ -37,7 +37,7 @@ int main()
   random_device rd;
   mt19937 gen(rd());
 
-  int64_t min = ipow(10, 9);
+  int64_t min = (int64_t) 1e9;
   int64_t max = min * 2;
   uniform_int_distribution<int64_t> dist(min, max);
   int threads = get_num_threads();
